@@ -1,5 +1,5 @@
-from typing import Iterable
 from abc import abstractmethod
+from typing import Iterable, Optional
 
 from .FormBase import FormBase
 from .ProcessBase import ProcessBase
@@ -9,7 +9,7 @@ class GUIApplicationBase(ProcessBase):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
         self._forms: Iterable[FormBase] = []
-        self._currentForm: FormBase = None
+        self._currentForm: Optional[FormBase] = None
 
     @property
     def forms(self) -> Iterable[FormBase]:
@@ -21,4 +21,4 @@ class GUIApplicationBase(ProcessBase):
 
     @abstractmethod
     def focus(self):
-        self.currentForm.focus()
+        pass
